<?php

/**
 * The CSS AutoLoader admin plugin class
 *
 * @since 5.0.0
 */
 
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * The admin plugin class
 */
if ( !class_exists( 'PP_Css_Autoloader_Admin' ) ) {
  
  class PP_Css_Autoloader_Admin extends PPF08_Admin {

    
    /**
	   * Do Init
     *
     * @since 5.0.0
     * @access public
     */
    public function init() {
      
      // @since 11.0.0
      $this->init_rating_notice( array( 
        'title'          => esc_html( 'Are you happy with the Smart CSS Auto Loader plugin?', 'css-autoloader' ),
        'subtitle'       => esc_html( 'You\'ve  been using this plugin for a while now. Would be great to get some feedback!', 'css-autoloader' ),
        'button_yes'     => esc_html( 'Yes, I\'m happy with it', 'css-autoloader' ),
        'button_no'      => esc_html( 'Not really', 'css-autoloader' ),
        'button_later'   => esc_html( 'Ask me later', 'css-autoloader' ),
        'button_close'   => esc_html( 'Never show again', 'css-autoloader' ),
        'like'           => esc_html( 'I\'m really glad you like it.  I do not ask for a donation. All I\'m asking you for is to give it a good rating. Thank you very much.', 'css-autoloader' ),
        'button_rate'    => esc_html( 'Yes, I\'d like to rate it', 'css-autoloader' ),
        'dislike'        => esc_html( 'I\'m really sorry you don\'t like it. Would you please do me a favor and drop me line, why you are not happy with it? Maybe I can do better...', 'css-autoloader' ),
        'button_contact' => esc_html( 'Yes sure', 'css-autoloader' )
      ),
      array(
        'rate'           => 'https://wordpress.org/support/plugin/' . $this->core()->get_plugin_slug() . '/reviews/',
        'contact'        => 'https://petersplugins.com/contact/'
      ));

      $this->add_actions( array( 
        'admin_init',
        'admin_menu'
      ) );
      
      add_filter( 'plugin_action_links_' . plugin_basename( $this->core()->get_plugin_file() ), array( $this, 'add_settings_links' ) ); 
    
    }
    
    
    /**
     * init admin 
     */
    function action_admin_init() {
      
		$this->add_setting_sections(
      
			[
      
				[
        
					'section' => 'general',
					'order'   => 10,
					'title'   => esc_html__( 'General', 'css-autoloader' ),
					'icon'    => 'general',
					'html'     => $this->show_current(),
					'nosubmit' => true
        
				]
			]
        
		);
      
    }
    
    
    /**
     * create the menu entry
     */
    function action_admin_menu() {
		
      $screen_id = add_theme_page ( $this->core()->get_plugin_name(), $this->core()->get_plugin_shortname(), 'manage_options', 'cssautoloader', array( $this, 'show_admin' ) );
      $this->set_screen_id( $screen_id );
	  
    }
    
   
   
    /**
     * show admin page
     */
    function show_admin() {
      
      $this->add_toolbar_icons( array(
        array( 
          'link'  => 'https://wordpress.org/support/plugin/' . $this->core()->get_plugin_slug() . '/reviews/',
          'title' => __( 'Please rate Plugin', 'css-autoloader' ),
          'icon'  => 'dashicons-star-filled'
        ),
        array( 
          'link'  => 'https://wordpress.org/plugins/' . $this->core()->get_plugin_slug(),
          'title' => __( 'WordPress.org Plugin Page', 'css-autoloader' ),
          'icon'  => 'dashicons-wordpress'
        ),
        array( 
          'link'  => 'https://wordpress.org/support/plugin/' . $this->core()->get_plugin_slug(),
          'title' => __( 'Support', 'css-autoloader' ),
          'icon'  => 'dashicons-editor-help'
        )
        
      ) );
      
      $this->show( 'manage_options' );
      
    }
    
    
    /**
     * add links to plugins table
     */
    function add_settings_links( $links ) {
		
      return array_merge( $links, array( '<a href="' . admin_url( 'themes.php?page=cssautoloader' ) . '" title="' . __( 'Show currently loaded files', 'css-autoloader' ) . '">' . __( 'Show currently loaded files', 'css-autoloader' ) . '</a>', '<a href="https://wordpress.org/support/plugin/' . $this->core()->get_plugin_slug() . '/reviews/" title="' . __( 'Please rate plugin', 'css-autoloader' ) . '">' . __( 'Please rate plugin', 'css-autoloader' ) . '</a>' ) );
      
    }
    
    
    /**
     * list currently loaded css files on admin page
	 * moved from main class in v 5.0.0
     */
    private function show_current() {
		
		$filesarray = $this->core()->getAllFiles();
		$possibledirs = $this->core()->getDirs();
		
		$list = '<h2>' . __( 'Currently loaded CSS files (in that order)', 'css-autoloader') . '</h2>';
      
		if ( empty( $filesarray ) ) {
			
			$list .= __( 'no files loaded currently', 'css-autoloader' );
      
		} else {
        
			$list .= '<table>';
			
			foreach ( $filesarray as $file ) {
				
				$list .= '<tr><th>URL</th><td><a href="' . $file['url'] . '">' . $file['url'] . '</a></td></tr>' .
				         '<tr><th>' . __( 'File', 'css-autoloader' ) . '</th><td><code>' . $file['name'] . '</code></td></tr>' .
				         '<tr><th>' . __( 'Media', 'css-autoloader' ) . '</th><td>' . $file['media'] .  '</td></tr>' .
						 '<tr><th>&nbsp;</th><td>&nbsp;</td></tr>';
			}
			
			$list .= '</table>';
		}
		
		$list .= '<h2>' . __( 'Possible paths to store your CSS files', 'css-autoloader') . '</h2>';
		
		$list .= '<table>';
        
		$list .= '<tr><th>' . __( 'General Directory', 'css-autoloader') . '</th>' .
                 '<td><code>' . $possibledirs['general']['dir'] . '</code></td></tr>';
				 
		$list .= '<tr><th>' . __( 'Theme Directory', 'css-autoloader') . '</th>' .
                 '<td><code>' . $possibledirs['theme']['dir'] . '</code></td></tr>';
				 
		$list .= '<tr><th>' . __( 'Child Theme Directory', 'css-autoloader') . '</th><td>';
           
		if ( $possibledirs['childtheme'] ) {
        
			$list .= '<code>' . $possibledirs['childtheme']['dir'] . '</code>';
		
		} else {
        
			$list .= __( 'You are not using a Child Theme', 'css-autoloader' );
        
		}
		
		$list .= '</td></tr></table><style> .pp-admin-page-inner th {text-align: left; padding-right: 6px; } </style>';
        
		return $list;
		
    }
  
  }
  
}

?>